==> qt-creator-opensource-src-4.0.0.zip: qt-creator-opensource-src-4.0.0/src/plugins/coreplugin/editormanager/systemeditor.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef SYSTEMEDITOR_H
#define SYSTEMEDITOR_H

#include "iexternaleditor.h"

namespace Core {
namespace Internal {

class SystemEditor : public IExternalEditor
{
    Q_OBJECT

public:
    explicit SystemEditor(QObject *parent = 0);

    QStringList mimeTypes() const;
    Id id() const;
    QString displayName() const;

    bool startEditor(const QString &fileName, QString *errorMessage);
};

} // namespace Internal
} // namespace Core

#endif // SYSTEMEDITOR_H

==> qt-creator-opensource-src-5.0.2.zip: qt-creator-opensource-src-5.0.2/src/plugins/coreplugin/editormanager/systemeditor.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "iexternaleditor.h"

namespace Core {
namespace Internal {

class SystemEditor : public IExternalEditor
{
    Q_OBJECT

public:
    explicit SystemEditor(QObject *parent = nullptr);

    QStringList mimeTypes() const override;
    Utils::Id id() const override;
    QString displayName() const override;

    bool startEditor(const Utils::FilePath &filePath, QString *errorMessage) override;
};

} // namespace Internal
} // namespace Core
